from django import forms

from benevalibre.utils.forms import CustomTapeformMixin

from . import models


class CreateForm(CustomTapeformMixin, forms.ModelForm):
    class Meta:
        model = models.Association
        fields = '__all__'

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        # We dynamically reload the choices to build a grouped select
        self.fields['activity_field'].choices = [
            (
                g.name,
                [
                    (f.id, f.name)
                    for f in models.ActivityField.objects.filter(
                        activity_field_group=g
                    )
                ],
            )
            for g in models.ActivityFieldGroup.objects.all()
        ]


class UpdateForm(CreateForm):
    pass


class ProjectCreateForm(CustomTapeformMixin, forms.ModelForm):
    class Meta:
        model = models.Project
        exclude = ('association',)


class ProjectUpdateForm(ProjectCreateForm):
    pass


class RoleCreateForm(CustomTapeformMixin, forms.ModelForm):
    class Meta:
        model = models.Role
        exclude = ('association',)


class RoleUpdateForm(RoleCreateForm):
    pass


class LevelCreateForm(CustomTapeformMixin, forms.ModelForm):
    class Meta:
        model = models.Level
        exclude = ('association',)


class LevelUpdateForm(LevelCreateForm):
    pass


class CategoryCreateForm(CustomTapeformMixin, forms.ModelForm):
    class Meta:
        model = models.Category
        exclude = ('association',)


class CategoryUpdateForm(CategoryCreateForm):
    pass


class EngagementUpdateForm(CustomTapeformMixin, forms.ModelForm):
    def __init__(self, *args, **kwargs):
        role_set = kwargs.pop('role_set')
        super().__init__(*args, **kwargs)
        self.fields['role'].queryset = role_set

    class Meta:
        model = models.Engagement
        fields = ('role',)


class FilterForm(CustomTapeformMixin, forms.Form):
    field_template = 'association/forms/fields/search.html'
    field_label_css_class = 'sr-only'
    widget_css_class = CustomTapeformMixin.widget_css_class + ' search-input'

    def apply_widget_options(self, field_name):
        field = self.fields[field_name]
        # utilise l'attribut placeholder au lieu du label
        field.widget.attrs['placeholder'] = field.label
