from django.core.exceptions import ValidationError

import pytest

from benevalibre.association import models


@pytest.mark.django_db
class TestCreatedActivityFields:
    def test_created_activity_fields(self):
        assert models.ActivityField.objects.count() == 55

    def test_created_activity_field_groups(self):
        assert models.ActivityFieldGroup.objects.count() == 8


@pytest.mark.django_db
class TestCreatedDefautsRelated:
    # No levels by defaut

    def test_created_default_roles(self, association):
        assert association.role_set.all().exists()
        assert (
            association.role_set.all().count()
            == models.DefaultRole.objects.all().count()
        )

    def test_created_default_categorys(self, association):
        assert association.category_set.all().exists()
        assert (
            association.category_set.all().count()
            == models.DefaultCategory.objects.all().count()
        )


@pytest.mark.django_db
class TestEngagements:
    def test_raise_exception_on_multiple_engagements(
        self, user, association, engagement, level, category, project
    ):
        """
        Un bénévole ne doit pas cumuler les engagements pour une association
        """

        with pytest.raises(ValidationError, match="rôle existant plutôt que"):
            user.engagement_set.create(
                association=association, role=association.role_set.last()
            )

    def test_raise_exception_on_engagement_error(
        self, user, association, level, category, project
    ):
        """
        Un engagement doit être lié à un rôle de l'association.
        """
        # spoof the related association
        role = association.role_set.last()
        dummy = association._meta.model.objects.create(name='blang')
        role.association = dummy

        with pytest.raises(ValidationError, match="rôle valide"):
            user.engagement_set.create(association=association, role=role)


@pytest.mark.django_db
class TestRoles:
    def test_raise_exception_on_multiple_new_comers_default_role(
        self, association
    ):
        with pytest.raises(ValidationError, match="possède déjà l'attribut"):
            association.role_set.create(name='bling', new_comers=True)

    def test_raise_exception_on_zero_new_comers_default_role(
        self, association
    ):
        role = association.role_set.get_benevole()
        role.new_comers = False

        with pytest.raises(ValidationError, match="ne possède l'attribut"):
            role.save()

    def test_asso_manager_can_manage_roles(
        self, association, foreign, engagement
    ):
        association.role_set.create(
            name="AssoManager", manage_association=True
        )
        association.engagement_set.create(
            user=foreign, role=association.role_set.get(name="AssoManager")
        )
        assert association.can_manage_association(foreign)
        assert association.can_manage_roles(foreign)
