import os.path

from django.template import Context, Template
from django.template.loader import render_to_string
from django.test.html import parse_html

import pytest


@pytest.mark.parametrize(
    'buttons, template_name',
    [
        (
            [
                {'label': "Foo", 'url': '/foo/'},
                {
                    'label': "Other class",
                    'url': '/other/',
                    'button_class': 'btn-other',
                },
                {
                    'label': "Extra classes",
                    'url': '/extra/',
                    'extra_classes': 'extra classes',
                },
                {
                    'label': "Other and extra classes",
                    'url': '/extra/',
                    'button_class': 'btn-other',
                    'extra_classes': 'extra classes',
                },
            ],
            'link.html',
        ),
        (
            [
                {
                    'label': "Dropdown button",
                    'submenu': [
                        {'label': "Foo", 'url': '/foo/'},
                        {
                            'label': "Extra classes",
                            'url': '/extra/',
                            'extra_classes': 'extra classes',
                        },
                        {'label': "Some text"},
                        {'extra_classes': 'dropdown-divider'},
                    ],
                },
                {
                    'label': "Dropdown button with other class",
                    'button_class': 'btn-other',
                    'extra_classes': 'extra classes',
                    'submenu': [{'label': "Foo", 'url': '/foo/'}],
                    'submenu_class': 'dropdown-menu-other',
                },
            ],
            'dropdown.html',
        ),
        (
            [
                {'label': "Foo"},
                {
                    'label': "Other and extra classes",
                    'button_class': 'btn-other',
                    'extra_classes': 'extra classes',
                },
            ],
            'button.html',
        ),
    ],
)
def test_buttons(buttons, template_name):
    template_path = os.path.join(
        os.path.dirname(__file__), 'templates/buttons', template_name
    )
    with open(template_path) as f:
        expected = Template(f.read()).render(Context())
    assert parse_html(
        render_to_string('includes/buttons.html', {'buttons': buttons})
    ) == parse_html(expected)
